===============================
tripleo-common
===============================

A common library for TripleO workflows.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/tripleo-common
* Source: http://git.openstack.org/cgit/openstack/tripleo-common
* Bugs: http://bugs.launchpad.net/tripleo-common

Features
--------

* TODO
